==> opencart_v1.5.0.zip: opencart_v1.5.0/upload/catalog/language/english/checkout/checkout.php <==
<?php
// Heading 
$_['heading_title']                  = 'Checkout';

// Text
$_['text_basket']                    = 'Basket';
$_['text_checkout_option']           = 'Step 1: Checkout Options';
$_['text_checkout_account']          = 'Step 2: Account &amp; Billing Details';
$_['text_checkout_payment_address']  = 'Step 2: Billing Details';
$_['text_checkout_shipping_address'] = 'Step 3: Delivery Details';
$_['text_checkout_shipping_method']  = 'Step 4: Delivery Method';
$_['text_checkout_payment_method']   = 'Step 5: Payment Method';
$_['text_checkout_confirm']          = 'Step 6: Confirm Order';
$_['text_modify']                    = 'Modify &raquo;';
$_['text_new_customer']              = 'New Customer';
$_['text_returning_customer']        = 'Returning Customer';
$_['text_checkout']                  = 'Checkout Options:';
$_['text_i_am_returning_customer']   = 'I am a returning customer';
$_['text_register']                  = 'Register Account';
$_['text_guest']                     = 'Guest Checkout';
$_['text_register_account']          = 'By creating an account you will be able to shop faster, be up to date on an order\'s status, and keep track of the orders you have previously made.';
$_['text_forgotten']                 = 'Forgotten Password';
$_['text_your_details']              = 'Your Personal Details';
$_['text_your_address']              = 'Your Address';
$_['text_your_password']             = 'Your Password';
$_['text_agree']                     = 'I have read and agree to the <a class="fancybox" href="%s" alt="%s"><b>%s</b></a>';
$_['text_address_new']               = 'I want to use a new billing address';
$_['text_address_existing']          = 'I want to use an existing billing address';
$_['text_shipping_method']           = 'Please select the preferred shipping method to use on this order.';
$_['text_payment_method']            = 'Please select the preferred payment method to use on this order.';
$_['text_comments']                  = 'Add Comments About Your Order';

// Column
$_['column_name']                    = 'Product Name';
$_['column_model']                   = 'Model';
$_['column_quantity']                = 'Quantity';
$_['column_price']                   = 'Price';
$_['column_total']                   = 'Total';

// Entry
$_['entry_email_address']            = 'E-Mail Address:';
$_['entry_email']                    = 'E-Mail:';
$_['entry_password']                 = 'Password:';
$_['entry_confirm']                  = 'Password Confirm:';
$_['entry_firstname']                = 'First Name:';
$_['entry_lastname']                 = 'Last Name:';
$_['entry_telephone']                = 'Telephone:';
$_['entry_fax']                      = 'Fax:';
$_['entry_company']                  = 'Company:';
$_['entry_address_1']                = 'Address 1:';
$_['entry_address_2']                = 'Address 2:';
$_['entry_postcode']                 = 'Post Code:';
$_['entry_city']                     = 'City:';
$_['entry_country']                  = 'Country:';
$_['entry_zone']                     = 'Region / State:';
$_['entry_newsletter']               = 'I wish to suscribe to the %s newsletter.';
$_['entry_shipping'] 	             = 'My delivery and billing addresses are the same.';

// Error
$_['error_warning']                  = 'There was a problem while trying to process your order! If the problem persists please try selecting a different payment method or you can contact the store owner by <a href="%s">clicking here</a>.';
$_['error_minimum']                  = 'Minimum order amount for %s is %s!';	
$_['error_login']                    = 'Error: No match for E-Mail Address and/or Password.';
$_['error_exists']                   = 'Error: E-Mail Address is already registered!';
$_['error_firstname']                = 'First Name must be between 1 and 32 characters!';
$_['error_lastname']                 = 'Last Name must be between 1 and 32 characters!';
$_['error_email']                    = 'E-Mail Address does not appear to be valid!';
$_['error_telephone']                = 'Telephone must be between 3 and 32 characters!';
$_['error_password']                 = 'Password must be between 3 and 20 characters!';
$_['error_confirm']                  = 'Password confirmation does not match password!';
$_['error_address_1']                = 'Address 1 must be between 3 and 128 characters!';
$_['error_city']                     = 'City must be between 2 and 128 characters!';
$_['error_postcode']                 = 'Postcode must be between 2 and 10 characters!';
$_['error_country']                  = 'Please select a country!';
$_['error_zone']                     = 'Please select a region / state!';
$_['error_agree']                    = 'Error: You must agree to the %s!';
$_['error_address']                  = 'Error: You must select address!';
$_['error_shipping']                 = 'Error: Shipping method required!';
$_['error_no_shipping']              = 'No Shipping options are available. Please <a href="%s">contact us</a> for assistance!';
$_['error_payment']                  = 'Error: Payment method required!';
$_['error_no_payment']               = 'Error: No Payment options are available. Please <a href="%s">contact us</a> for assistance!';
?>

==> opencart_v1.5.4.1.zip: opencart_v1.5.4.1/upload/catalog/language/english/checkout/checkout.php <==
<?php
// Heading 
$_['heading_title']                  = 'Checkout';

// Text
$_['text_cart']                      = 'Shopping Cart';
$_['text_checkout_option']           = 'Step 1: Checkout Options';
$_['text_checkout_account']          = 'Step 2: Account &amp; Billing Details';
$_['text_checkout_payment_address']  = 'Step 2: Billing Details';
$_['text_checkout_shipping_address'] = 'Step 3: Delivery Details';
$_['text_checkout_shipping_method']  = 'Step 4: Delivery Method';
$_['text_checkout_payment_method']   = 'Step 5: Payment Method';
$_['text_checkout_confirm']          = 'Step 6: Confirm Order';
$_['text_modify']                    = 'Modify &raquo;';
$_['text_new_customer']              = 'New Customer';
$_['text_returning_customer']        = 'Returning Customer';
$_['text_checkout']                  = 'Checkout Options:';
$_['text_i_am_returning_customer']   = 'I am a returning customer';
$_['text_register']                  = 'Register Account';
$_['text_guest']                     = 'Guest Checkout';
$_['text_register_account']          = 'By creating an account you will be able to shop faster, be up to date on an order\'s status, and keep track of the orders you have previously made.';
$_['text_forgotten']                 = 'Forgotten Password';
$_['text_your_details']              = 'Your Personal Details';
$_['text_your_address']              = 'Your Address';
$_['text_your_password']             = 'Your Password';
$_['text_agree']                     = 'I have read and agree to the <a class="colorbox" href="%s" alt="%s"><b>%s</b></a>';
$_['text_address_new']               = 'I want to use a new address';
$_['text_address_existing']          = 'I want to use an existing address';
$_['text_shipping_method']           = 'Please select the preferred shipping method to use on this order.';
$_['text_payment_method']            = 'Please select the preferred payment method to use on this order.';
$_['text_comments']                  = 'Add Comments About Your Order';

// Column
$_['column_name']                    = 'Product Name';
$_['column_model']                   = 'Model';
$_['column_quantity']                = 'Quantity';
$_['column_price']                   = 'Price';
$_['column_total']                   = 'Total';

// Entry
$_['entry_email_address']            = 'E-Mail Address:';
$_['entry_email']                    = 'E-Mail:';
$_['entry_password']                 = 'Password:';
$_['entry_confirm']                  = 'Password Confirm:';
$_['entry_firstname']                = 'First Name:';
$_['entry_lastname']                 = 'Last Name:';
$_['entry_telephone']                = 'Telephone:';
$_['entry_fax']                      = 'Fax:';
$_['entry_company']                  = 'Company:';
$_['entry_customer_group']           = 'Business Type:';
$_['entry_company_id']               = 'Company ID:';
$_['entry_tax_id']                   = 'Tax ID:';
$_['entry_address_1']                = 'Address 1:';
$_['entry_address_2']                = 'Address 2:';
$_['entry_postcode']                 = 'Post Code:';
$_['entry_city']                     = 'City:';
$_['entry_country']                  = 'Country:';
$_['entry_zone']                     = 'Region / State:';
$_['entry_newsletter']               = 'I wish to subscribe to the %s newsletter.';
$_['entry_shipping'] 	             = 'My delivery and billing addresses are the same.';

// Error
$_['error_warning']                  = 'There was a problem while trying to process your order! If the problem persists please try selecting a different payment method or you can contact the store owner by <a href="%s">clicking here</a>.';
$_['error_login']                    = 'Warning: No match for E-Mail Address and/or Password.';
$_['error_approved']                 = 'Warning: Your account requires approval before you can login.'; 
$_['error_exists']                   = 'Warning: E-Mail Address is already registered!';
$_['error_firstname']                = 'First Name must be between 1 and 32 characters!';
$_['error_lastname']                 = 'Last Name must be between 1 and 32 characters!';
$_['error_email']                    = 'E-Mail Address does not appear to be valid!';
$_['error_telephone']                = 'Telephone must be between 3 and 32 characters!';
$_['error_password']                 = 'Password must be between 3 and 20 characters!';
$_['error_confirm']                  = 'Password confirmation does not match password!';
$_['error_company_id']               = 'Company ID required!';
$_['error_tax_id']                   = 'Tax ID required!';
$_['error_vat']                      = 'VAT number is invalid!';
$_['error_address_1']                = 'Address 1 must be between 3 and 128 characters!';
$_['error_city']                     = 'City must be between 2 and 128 characters!';
$_['error_postcode']                 = 'Postcode must be between 2 and 10 characters!';
$_['error_country']                  = 'Please select a country!';
$_['error_zone']                     = 'Please select a region / state!';
$_['error_agree']                    = 'Warning: You must agree to the %s!';
$_['error_address']                  = 'Warning: You must select address!';
$_['error_shipping']                 = 'Warning: Shipping method required!';
$_['error_no_shipping']              = 'Warning: No Shipping options are available. Please <a href="%s">contact us</a> for assistance!';
$_['error_payment']                  = 'Warning: Payment method required!';
$_['error_no_payment']               = 'Warning: No Payment options are available. Please <a href="%s">contact us</a> for assistance!';
?>
